@@ -1,11 +1,12 @@
 """This module contains the GroupOperation domain model."""
 
 from pydantic import BaseModel, Field
-
+from typing import Optional
 
 class GroupOperationRequest(BaseModel):
     group_id: str = Field(alias="groupId")
     type_: str = Field(alias="type")
+    project_id: Optional[str] = Field(alias="projectId")
 
     class Config:
         allow_population_by_field_name = True
@@ -21,7 +22,10 @@ class GroupOperationRequest(BaseModel):
 
     @property
     def payload(self):
-        return {"type": self.type_}
+        payload = {"type": self.type_}
+        if self.type_ == "add_to_project":
+            payload["projectId"] = self.project_id
+        return payload
 
     @property
     def headers(self):
